@@ -60,10 +60,9 @@ private:
 
     // A parent object for QObjects that are created dynamically based on settings
     // Used to simplify the setting cleanup on reconfiguration: deleting settingOwner frees all related QObjects
-    QWidget *settingOwner;
+    QObject *settingOwner;
 
     QMenu *presetsMenu;
-    bool m_removeFinished;
     TerminalConfig m_config;
 
     QDockWidget *m_bookmarksDock;
@@ -105,7 +104,6 @@ private slots:
     void actAbout_triggered();
     void actProperties_triggered();
     void updateActionGroup(QAction *);
-    void testClose(bool removeFinished);
     void toggleBookmarks();
     void toggleBorderless();
     void toggleTabBar();
@@ -119,7 +117,7 @@ private slots:
     void bookmarksWidget_callCommand(const QString&);
     void bookmarksDock_visibilityChanged(bool visible);
 
-    void addNewTab();
+    void addNewTab(TerminalConfig cfg = TerminalConfig());
     void onCurrentTitleChanged(int index);
 
     void handleHistory();
