@@ -8,7 +8,7 @@
 #include "properties.h"
 #include "termwidget.h"
 
-TerminalConfig::TerminalConfig(const QString & wdir, const QString & shell)
+TerminalConfig::TerminalConfig(const QString & wdir, const QStringList & shell)
 {
     m_workingDirectory = wdir;
     m_shell = shell;
@@ -32,20 +32,20 @@ QString TerminalConfig::getWorkingDirectory()
     return QTerminalApp::Instance()->getWorkingDirectory();
 }
 
-QString TerminalConfig::getShell()
+QStringList TerminalConfig::getShell()
 {
-    if (!m_shell.trimmed().isEmpty())
-        return m_shell.trimmed();
-    if (!Properties::Instance()->shell.trimmed().isEmpty())
-        return Properties::Instance()->shell.trimmed();
+    if (!m_shell.isEmpty())
+        return m_shell;
+    if (!Properties::Instance()->shell.isEmpty())
+        return Properties::Instance()->shell;
     QByteArray envShell = qgetenv("SHELL");
     if (envShell.constData() != nullptr)
     {
         QString shellString = QString::fromLocal8Bit(envShell).trimmed();
         if (!shellString.isEmpty())
-            return shellString;
+            return QStringList{shellString};
     }
-    return QString();
+    return QStringList();
 }
 
 void TerminalConfig::setWorkingDirectory(const QString &val)
@@ -53,7 +53,7 @@ void TerminalConfig::setWorkingDirectory(const QString &val)
     m_workingDirectory = val;
 }
 
-void TerminalConfig::setShell(const QString &val)
+void TerminalConfig::setShell(const QStringList &val)
 {
     m_shell = val;
 }
@@ -87,16 +87,23 @@ static QString variantToString(const QVariant& variant, QString &defaultVal)
     return defaultVal;
 }
 
+static QStringList variantToStringList(const QVariant& variant, QStringList &defaultVal)
+{
+    if (variant.type() == QVariant::StringList)
+        return qvariant_cast<QStringList>(variant);
+    return defaultVal;
+}
+
 TerminalConfig TerminalConfig::fromDbus(const QHash<QString,QVariant> &termArgs)
 {
     QString wdir = QString();
-    QString shell(Properties::Instance()->shell);
+    QStringList shell(Properties::Instance()->shell);
     if (termArgs.contains(QLatin1String(DBUS_ARG_WORKDIR)))
     {
         wdir = variantToString(termArgs[QLatin1String(DBUS_ARG_WORKDIR)], wdir);
     }
     if (termArgs.contains(QLatin1String(DBUS_ARG_SHELL))) {
-        shell = variantToString(termArgs[QLatin1String(DBUS_ARG_SHELL)], shell);
+        shell = variantToStringList(termArgs[QLatin1String(DBUS_ARG_SHELL)], shell);
     }
     return TerminalConfig(wdir, shell);
 }
